@@ -90,9 +90,8 @@ def convert_py_float_to_cffi( x):
 
 
 def convert_py_int_to_cffi( x):
-    if isinstance( x, np.ndarray) or x != None:
-        if not isinstance( x, np.ndarray) or ( x.flags.c_contiguous == False):
-            px = np.ascontiguousarray( np.intc( x))    
+    if x != None:
+        px = np.ascontiguousarray( np.intc( x))    
     else: 
         # handle None
         px = np.array( 0)     
